@@ -2,33 +2,14 @@
 //!
 //! For help on how to get started, take a look at the [examples](https://github.com/elast0ny/shared_memory-rs/tree/master/examples) !
 
-// Allow dependents to disable logging through the "logging" feature
-cfg_if::cfg_if! {
-    if #[cfg(feature = "logging")] {
-        pub(crate) use log;
-    } else {
-        #[allow(unused_macros)]
-        #[macro_use]
-        pub (crate) mod log {
-            macro_rules! trace (($($tt:tt)*) => {{}});
-            macro_rules! debug (($($tt:tt)*) => {{}});
-            macro_rules! info (($($tt:tt)*) => {{}});
-            macro_rules! warn  (($($tt:tt)*) => {{}});
-            macro_rules! error (($($tt:tt)*) => {{}});
-        }
-    }
-}
-
-#[allow(unused_imports)]
-use crate::log::*;
-
 use std::fs::{File, OpenOptions};
 use std::io::{ErrorKind, Read, Write};
 
 use std::fs::remove_file;
 use std::path::{Path, PathBuf};
 
-use ::cfg_if::*;
+use cfg_if::cfg_if;
+use log::*;
 
 mod error;
 pub use error::*;
@@ -46,6 +27,7 @@ cfg_if! {
     }
 }
 
+#[derive(Clone)]
 /// Struct used to configure different parameters before creating a shared memory mapping
 pub struct ShmemConf {
     owner: bool,
@@ -65,10 +47,8 @@ impl Drop for ShmemConf {
         }
     }
 }
-#[allow(clippy::new_without_default)]
-impl ShmemConf {
-    /// Create a new default shmem config
-    pub fn new() -> Self {
+impl Default for ShmemConf {
+    fn default() -> Self {
         Self {
             owner: false,
             os_id: None,
@@ -77,6 +57,12 @@ impl ShmemConf {
             size: 0,
         }
     }
+}
+impl ShmemConf {
+    /// Create a new default shmem config
+    pub fn new() -> Self {
+        ShmemConf::default()
+    }
     /// Provide a specific os identifier for the mapping
     ///
     /// When not specified, a randomly generated identifier will be used
